# ChannelAttenuationState


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**state** | **float** |  | [optional] 

## Example

```python
from DeviceServer.models.channel_attenuation_state import ChannelAttenuationState

# TODO update the JSON string below
json = "{}"
# create an instance of ChannelAttenuationState from a JSON string
channel_attenuation_state_instance = ChannelAttenuationState.from_json(json)
# print the JSON string representation of the object
print(ChannelAttenuationState.to_json())

# convert the object into a dict
channel_attenuation_state_dict = channel_attenuation_state_instance.to_dict()
# create an instance of ChannelAttenuationState from a dict
channel_attenuation_state_from_dict = ChannelAttenuationState.from_dict(channel_attenuation_state_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


